==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>प्रोटोकॉल</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>सुरक्षा प्रकार</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>बैंड </translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>चैनल </translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>इंटरफेस </translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>प्राथमिक DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>गति</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>उपकरण निष्क्रिय है</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्ट है परंतु नेटवर्क हेतु अभिगम नहीं है </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल हटी हुई है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>प्रमाणीकृत किया जा रहा है</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP अड्रेस प्राप्त किया जा रहा है</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>कनेक्ट है </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>डिस्कनेक्ट है</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>विफल रहा</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>नेटवर्क पता प्राप्त करना जारी</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>केबल नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>केबल नेटवर्क %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>केबल रहित नेटवर्क</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>केबल रहित नेटवर्क %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>उपकरण निष्क्रिय है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल हटी हुई है</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्ट है परंतु नेटवर्क हेतु अभिगम नहीं है </translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>कनेक्ट करना विफल रहा</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>केबल कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>केबल कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>केबल रहित कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>केबल रहित कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>नेटवर्क निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>नेटवर्क सक्रिय करें</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>नेटवर्क सेटिंग्स</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dock-network-plugin/translations/dock-network-plugin_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>केबल रहित नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>केबल नेटवर्क</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>नेटवर्क </translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>छुपे नेटवर्क से जुड़ें</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>कूटशब्द</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>कनेक्ट करें</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>हॉटस्पॉट</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>प्रोटोकॉल</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>सुरक्षा प्रकार</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>चैनल </translation>
    </message>
    <message>
        <source>Band</source>
        <translation>बैंड </translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>इंटरफेस </translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>आईपीवी4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>नेटवर्क गेटवे</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>प्राथमिक DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>आईपीवी6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>नेटवर्क उपसर्ग </translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>गति</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>उपकरण निष्क्रिय है</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्ट है परंतु नेटवर्क हेतु अभिगम नहीं है </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल हटी हुई है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>प्रमाणीकृत किया जा रहा है</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP अड्रेस प्राप्त किया जा रहा है</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>कनेक्ट है </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>डिस्कनेक्ट है</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>विफल रहा</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>नेटवर्क पता प्राप्त करना जारी</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>केबल नेटवर्क</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>केबल नेटवर्क %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>केबल रहित नेटवर्क</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>केबल रहित नेटवर्क %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>उपकरण निष्क्रिय है</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>नेटवर्क केबल हटी हुई है</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>कनेक्ट नहीं है</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>कनेक्ट हो रहा है </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>कनेक्ट है परंतु नेटवर्क हेतु अभिगम नहीं है </translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>कनेक्ट करना विफल रहा</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>आईपी विरोधाभास</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>केबल कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>केबल कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>केबल रहित कनेक्शन निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>केबल रहित कनेक्शन सक्रिय करें</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>नेटवर्क निष्क्रिय करें</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>नेटवर्क सक्रिय करें</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>नेटवर्क सेटिंग्स</translation>
    </message>
</context>
</TS>
